@@ -10,6 +10,8 @@
 #' @param scaled logical If \code{TRUE} relative units are assumed.
 #' @param normalized logical (\code{FALSE}) or numeric Normalization wavelength
 #'   in manometers (nm).
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #'
 #' @return a character string or an R expression.
 #'
@@ -29,12 +31,21 @@ cps_label <- function(unit.exponent = 0,
                                          default = "R.expression"),
                       label.text = axis_labels()[["cps"]],
                       scaled = FALSE,
-                      normalized = FALSE) {
+                      normalized = FALSE,
+                      axis.symbols = getOption("ggspectra.axis.symbols",
+                                              default = TRUE)) {
+  if (!axis.symbols) {
+    label.text <- gsub(",$", "", label.text)
+  }
   if (scaled) {
     if (tolower(format) == "latex") {
       paste(label.text, "rate $n_{\\lambda}$ (rel.\ units)")
     } else if (format == "R.expression") {
-      bquote(.(label.text)~italic(n)[lambda]~plain((rel.~units)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(n)[lambda]~plain((rel.~units)))
+      } else {
+        bquote(.(label.text)~plain((rel.~units)))
+      }
     } else if (format == "R.character") {
       paste(label.text, "n(lambda) (rel. units)")
     }
@@ -42,7 +53,11 @@ cps_label <- function(unit.exponent = 0,
     if (tolower(format) == "latex") {
       paste(label.text, " rate $n_{\\lambda} / N_{", normalized, "}$ (/1)", sep = "")
     } else if (format == "R.expression") {
-      bquote(.(label.text)~italic(n)[lambda]/italic(n)[.(normalized)]~plain("(/1)"))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(n)[lambda]/italic(n)[.(normalized)]~plain("(/1)"))
+      } else {
+        bquote(.(label.text)*"normalised,"~plain("(/1)"))
+      }
     } else if (format == "R.character") {
       paste(label.text, "n(lambda) (norm. at", normalized, "nm)")
     }
@@ -57,10 +72,17 @@ cps_label <- function(unit.exponent = 0,
       }
     } else if (format %in% c("R.expression")) {
       if (unit.exponent == 0) {
-        bquote(.(label.text)~italic(n)[lambda]~(plain(counts)~s^{-1}))
+        if (axis.symbols) {
+          bquote(.(label.text)~italic(n)[lambda]~(plain(counts)~s^{-1}))
+        } else {
+          bquote(.(label.text)~(plain(counts)~s^{-1}))
+        }
       } else {
-        bquote(.(label.text)~italic(n)[lambda]~(10^{.(unit.exponent)}*plain(counts)~s^{-1}))
-
+        if (axis.symbols) {
+          bquote(.(label.text)~italic(n)[lambda]~(10^{.(unit.exponent)}*plain(counts)~s^{-1}))
+        } else {
+          bquote(.(label.text)~(10^{.(unit.exponent)}*plain(counts)~s^{-1}))
+        }
       }
     } else if (format == "R.character" && unit.exponent == 0) {
       paste(label.text, "n(lambda) (counts/s)")
@@ -85,6 +107,8 @@ cps_label <- function(unit.exponent = 0,
 #' @param scaled logical If \code{TRUE} relative units are assumed.
 #' @param normalized logical (\code{FALSE}) or numeric Normalization wavelength
 #'   in manometers (nm).
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #' @param ... other named arguments passed to \code{scale_y_continuous}
 #'
 #' @note This function only alters two default arguments, please, see
@@ -122,13 +146,16 @@ scale_y_cps_continuous <-
                             format = format,
                             label.text = label.text,
                             scaled = scaled,
-                            normalized = round(normalized, 1)),
+                            normalized = round(normalized, 1),
+                            axis.symbols = axis.symbols),
            labels = SI_pl_format(exponent = unit.exponent),
            format = getOption("photobiology.math",
                               default = "R.expression"),
            label.text = axis_labels()[["cps"]],
            scaled = FALSE,
            normalized = FALSE,
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_y_continuous(name = name,
                        labels = labels,
