@@ -1,16 +1,18 @@
-#' spectral irradiance axis labels
+#' Spectral irradiance axis labels
 #'
-#' Generate axis labels in SI units,
+#' Generate axis labels for spectral irradiance in SI units,
 #' using SI scale factors. Output can be selected as character, expression (R
 #' default devices) or LaTeX (for tikz device).
 #'
-#' @param unit.exponent integer
+#' @param unit.exponent integer.
 #' @param format character string, "R", "R.expresion", "R.character", or
 #'   "LaTeX".
 #' @param label.text character Textual portion of the labels.
 #' @param scaled logical If \code{TRUE} relative units are assumed.
 #' @param normalized logical (\code{FALSE}) or numeric Normalization wavelength
 #'   in manometers (nm).
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the \code{name}. Supported only by \code{format = "R.expression"}.
 #'
 #' @return a character string or an R expression.
 #'
@@ -18,21 +20,37 @@
 #'
 #' @examples
 #'
-#' counts_label()
-#' counts_label("R.expression")
-#' counts_label("LaTeX")
+#' str(s.e.irrad_label())
+#' str(s.e.irrad_label(axis.symbols = FALSE))
+#' str(s.e.irrad_label(format = "R.expression"))
+#' str(s.e.irrad_label(format = "LaTeX"))
+#'
+#'
+#' str(s.q.irrad_label())
+#' str(s.q.irrad_label(axis.symbols = FALSE))
+#' str(s.q.irrad_label(format = "R.expression"))
+#' str(s.q.irrad_label(format = "LaTeX"))
 #'
 s.e.irrad_label <- function(unit.exponent = 0,
                             format = getOption("photobiology.math",
                                                default = "R.expression"),
                             label.text = axis_labels()[["s.e.irrad"]],
                             scaled = FALSE,
-                            normalized = FALSE) {
+                            normalized = FALSE,
+                            axis.symbols = getOption("ggspectra.axis.symbols",
+                                                    default = TRUE)) {
+  if (!axis.symbols) {
+    label.text <- gsub(",$", "", label.text)
+  }
   if (scaled) {
     if (tolower(format) == "latex") {
       paste(label.text, "$E_{\\lambda}$ (rel.\ units)")
     } else if (format == "R.expression") {
-      bquote(.(label.text)~italic(E)[lambda]~plain((rel.~units)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(E)[lambda]~plain((rel.~units)))
+      } else {
+        bquote(.(label.text)~plain((rel.~units)))
+      }
     } else if (format == "R.character") {
       paste(label.text, "E(lambda) (rel. units)")
     }
@@ -40,7 +58,11 @@ s.e.irrad_label <- function(unit.exponent = 0,
     if (tolower(format) == "latex") {
       paste(label.text, " $E_{\\lambda} / E_{", normalized, "}$ (/1)", sep = "")
     } else if (format == "R.expression") {
-      bquote(.(label.text)~italic(E)[lambda]/italic(E)[.(normalized)]~plain("(/1)"))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(E)[lambda]/italic(E)[.(normalized)]~plain("(/1)"))
+      } else {
+        bquote(.(label.text)*", normalised"~plain("(/1)"))
+      }
     } else if (format == "R.character") {
       paste(label.text, "E(lambda) (norm. at", normalized, "nm)")
     }
@@ -58,9 +80,17 @@ s.e.irrad_label <- function(unit.exponent = 0,
     } else if (format %in% c("R.expression")) {
       if (has_SI_prefix(unit.exponent)) {
         prefix <- exponent2prefix(unit.exponent)
-        bquote(.(label.text)~italic(E)[lambda]~(plain(.(prefix))*plain(W~m^{-2}~nm^{-1})))
+        if (axis.symbols) {
+          bquote(.(label.text)~italic(E)[lambda]~(plain(.(prefix))*plain(W~m^{-2}~nm^{-1})))
+        } else {
+          bquote(.(label.text)~(plain(.(prefix))*plain(W~m^{-2}~nm^{-1})))
+        }
       } else {
-        bquote(.(label.text)~italic(E)[lambda]~(10^{.(unit.exponent)}~plain(W~m^{-2}~nm^{-1})))
+        if (axis.symbols) {
+          bquote(.(label.text)~italic(E)[lambda]~(10^{.(unit.exponent)}~plain(W~m^{-2}~nm^{-1})))
+        } else {
+          bquote(.(label.text)~(10^{.(unit.exponent)}~plain(W~m^{-2}~nm^{-1})))
+        }
       }
     } else if (format == "R.character" &&
                has_SI_prefix(unit.exponent)) {
@@ -83,12 +113,21 @@ s.q.irrad_label <- function(unit.exponent = ifelse(normalized, 0, -6),
                                                default = "R.expression"),
                             label.text = axis_labels()[["s.q.irrad"]],
                             scaled = FALSE,
-                            normalized = FALSE) {
+                            normalized = FALSE,
+                            axis.symbols = getOption("ggspectra.axis.symbols",
+                                                    default = TRUE)) {
+  if (!axis.symbols) {
+    label.text <- gsub(",$", "", label.text)
+  }
   if (scaled) {
     if (tolower(format) == "latex") {
       paste(label.text, "$Q_{\\lambda}$ (rel.\ units)")
     } else if (format == "R.expression") {
-      bquote(.(label.text)~italic(Q)[lambda]~plain((rel.~units)))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(Q)[lambda]~plain((rel.~units)))
+      } else {
+        bquote(.(label.text)~plain((rel.~units)))
+      }
     } else if (format == "R.character") {
       paste(label.text, "Q(lambda) (rel. units)")
     }
@@ -96,7 +135,11 @@ s.q.irrad_label <- function(unit.exponent = ifelse(normalized, 0, -6),
     if (tolower(format) == "latex") {
       paste(label.text, " $Q_{\\lambda} / Q_{", normalized, "}$ (/1)", sep = "")
     } else if (format == "R.expression") {
-      bquote(.(label.text)~italic(Q)[lambda]/italic(Q)[.(normalized)]~plain("(/1)"))
+      if (axis.symbols) {
+        bquote(.(label.text)~italic(Q)[lambda]/italic(Q)[.(normalized)]~plain("(/1)"))
+      } else {
+        bquote(.(label.text)*", normalised"~plain("(/1)"))
+      }
     } else if (format == "R.character") {
       paste(label.text, "Q(lambda) (norm. at", normalized, "nm)")
     }
@@ -114,7 +157,11 @@ s.q.irrad_label <- function(unit.exponent = ifelse(normalized, 0, -6),
     } else if (format %in% c("R.expression")) {
       if (has_SI_prefix(unit.exponent)) {
         prefix <- exponent2prefix(unit.exponent)
-        bquote(.(label.text)~italic(Q)[lambda]~(plain(.(prefix))*mol~s^{-1}~m^{-2}~nm^{-1}))
+        if (axis.symbols) {
+          bquote(.(label.text)~italic(Q)[lambda]~(plain(.(prefix))*mol~s^{-1}~m^{-2}~nm^{-1}))
+        } else {
+          bquote(.(label.text)~(plain(.(prefix))*mol~s^{-1}~m^{-2}~nm^{-1}))
+        }
       } else {
         bquote(.(label.text)~italic(Q)[lambda]~(10^{.(unit.exponent)}*mol~s^{-1}~m^{-2}~nm^{-1}))
       }
@@ -143,6 +190,8 @@ s.q.irrad_label <- function(unit.exponent = ifelse(normalized, 0, -6),
 #' @param scaled logical If \code{TRUE} relative units are assumed.
 #' @param normalized logical (\code{FALSE}) or numeric Normalization wavelength
 #'   in manometers (nm).
+#' @param axis.symbols logical If \code{TRUE} symbols of the quantities are
+#'   added to the default \code{name}.
 #' @param ... other named arguments passed to \code{scale_y_continuous}
 #'
 #' @note This function only alters two default arguments, please, see
@@ -204,13 +253,16 @@ scale_y_s.e.irrad_continuous <-
                                   format = format,
                                   label.text = label.text,
                                   scaled = scaled,
-                                  normalized = round(normalized, 1)),
+                                  normalized = round(normalized, 1),
+                                  axis.symbols = axis.symbols),
            labels = SI_pl_format(exponent = unit.exponent),
            format = getOption("photobiology.math",
                               default = "R.expression"),
            label.text = axis_labels()[["s.e.irrad"]],
            scaled = FALSE,
            normalized = FALSE,
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_y_continuous(name = name,
                        labels = labels,
@@ -227,13 +279,16 @@ scale_y_s.q.irrad_continuous <-
                                   format = format,
                                   label.text = label.text,
                                   scaled = scaled,
-                                  normalized = round(normalized, 1)),
+                                  normalized = round(normalized, 1),
+                                  axis.symbols = axis.symbols),
            labels = SI_pl_format(exponent = unit.exponent),
            format = getOption("photobiology.math",
                               default = "R.expression"),
            label.text = axis_labels()[["s.q.irrad"]],
            scaled = FALSE,
            normalized = FALSE,
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_y_continuous(name = name,
                        labels = labels,
@@ -250,13 +305,16 @@ scale_y_s.e.irrad_log10 <-
                                   format = format,
                                   label.text = label.text,
                                   scaled = scaled,
-                                  normalized = round(normalized, 1)),
+                                  normalized = round(normalized, 1),
+                                  axis.symbols = axis.symbols),
            labels = SI_pl_format(exponent = unit.exponent),
            format = getOption("photobiology.math",
                               default = "R.expression"),
            label.text = axis_labels()[["s.e.irrad"]],
            scaled = FALSE,
            normalized = FALSE,
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_y_log10(name = name,
                   labels = labels,
@@ -273,13 +331,16 @@ scale_y_s.q.irrad_log10 <-
                                   format = format,
                                   label.text = label.text,
                                   scaled = scaled,
-                                  normalized = round(normalized, 1)),
+                                  normalized = round(normalized, 1),
+                                  axis.symbols = axis.symbols),
            labels = SI_pl_format(exponent = unit.exponent),
            format = getOption("photobiology.math",
                               default = "R.expression"),
            label.text = axis_labels()[["s.q.irrad"]],
            scaled = FALSE,
            normalized = FALSE,
+           axis.symbols = getOption("ggspectra.axis.symbols",
+                                   default = TRUE),
            ...) {
     scale_y_log10(name = name,
                        labels = labels,
